@@ -16,10 +16,7 @@
 #' Calls [MASS::lda()] from package \CRANpkg{MASS}.
 #'
 #' @references
-#' William N. Venables, Brian D. Ripley (2002).
-#' Modern Applied Statistics with S.
-#' Fourth Edition. Springer, New York. ISBN 0-387-95457-0.
-#' \doi{10.1007/978-0-387-21706-2}.
+#' \cite{mlr3learners}{venables_2002}
 #'
 #' @export
 #' @template seealso_learner
@@ -39,7 +36,8 @@ LearnerClassifLDA = R6Class("LearnerClassifLDA", inherit = LearnerClassif,
         predict_types = c("response", "prob"),
         feature_types = c("logical", "integer", "numeric", "factor", "ordered"),
         properties = c("weights", "twoclass", "multiclass"),
-        packages = "MASS"
+        packages = "MASS",
+        man = "mlr3learners::mlr_learners_classif.lda"
       )
     },
 
