@@ -15,9 +15,7 @@
 #' A learner for a classification support vector machine implemented in [e1071::svm()].
 #'
 #' @references
-#' Corinna Cortes, Vladimir Vapnik (1995).
-#' Machine Learning 20: 273.
-#' \doi{10.1007/BF00994018}.
+#' \cite{mlr3learners}{cortes_1995}
 #'
 #' @export
 #' @template seealso_learner
@@ -48,15 +46,18 @@ LearnerClassifSVM = R6Class("LearnerClassifSVM", inherit = LearnerClassif,
         predict_types = c("response", "prob"),
         feature_types = c("integer", "numeric"),
         properties = c("twoclass", "multiclass"),
-        packages = "e1071"
+        packages = "e1071",
+        man = "mlr3learners::mlr_learners_classif.svm"
       )
     },
 
     train_internal = function(task) {
       pars = self$param_set$get_values(tags = "train")
+      data = as.matrix(task$data(cols = task$feature_names))
+      self$state$feature_names = colnames(data)
 
       invoke(e1071::svm,
-        x = as.matrix(task$data(cols = task$feature_names)),
+        x = data,
         y = task$truth(),
         probability = (self$predict_type == "prob"),
         .args = pars
@@ -66,6 +67,7 @@ LearnerClassifSVM = R6Class("LearnerClassifSVM", inherit = LearnerClassif,
     predict_internal = function(task) {
       pars = self$param_set$get_values(tags = "predict")
       newdata = as.matrix(task$data(cols = task$feature_names))
+      newdata = newdata[, self$state$feature_names, drop = FALSE]
       p = invoke(predict, self$model, newdata = newdata, probability = (self$predict_type == "prob"), .args = pars)
 
       PredictionClassif$new(task = task,
