@@ -16,15 +16,9 @@
 #' Calls [ranger::ranger()] from package \CRANpkg{ranger}.
 #'
 #' @references
-#' Marvin N. Wright, Andreas Ziegler (2017).
-#' ranger: A Fast Implementation of Random Forests for High Dimensional Data in C++ and R.
-#' Journal of Statistical Software, 77(1), 1-17.
-#' \doi{10.18637/jss.v077.i01}.
+#' \cite{mlr3learners}{wright_2017}
 #'
-#' Breiman, L. (2001).
-#' Random Forests.
-#' Machine Learning 45(1).
-#' \doi{10.1023/A:1010933404324}.
+#' \cite{mlr3learners}{breiman_2001}
 #'
 #' @export
 #' @template seealso_learner
@@ -62,7 +56,8 @@ LearnerRegrRanger = R6Class("LearnerRegrRanger", inherit = LearnerRegr,
         predict_types = c("response", "se"),
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
         properties = c("weights", "importance", "oob_error"),
-        packages = "ranger"
+        packages = "ranger",
+        man = "mlr3learners::mlr_learners_regr.ranger"
       )
     },
 
